#
# spec file for package jdom
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jdom
Version:        1.1.3
Release:        42.3
Summary:        Java alternative to DOM and SAX
License:        Saxpath
URL:            http://www.jdom.org/
Source0:        http://jdom.org/dist/binary/archive/jdom-%{version}.tar.gz
Source1:        https://repo1.maven.org/maven2/org/jdom/jdom/%{version}/jdom-%{version}.pom
Patch0:         %{name}-crosslink.patch
Patch1:         %{name}-1.1-OSGiManifest.patch
Patch2:         no-jaxen.patch
Patch10:        CVE-2021-33813.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
BuildArch:      noarch

%description
JDOM is, quite simply, a Java representation of an XML document. JDOM
provides a way to represent that document for easy and efficient
reading, manipulation, and writing. It has a straightforward API, is a
lightweight and fast, and is optimized for the Java programmer. It's an
alternative to DOM and SAX, although it integrates well with both DOM
and SAX.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
Javadoc for %{name}.

%package demo
Summary:        Demos for %{name}
Requires:       %{name} = %{version}-%{release}

%description demo
Demonstrations and samples for %{name}.

%prep
%setup -q -n %{name}
%patch -P 0
%patch -P 1
%patch -P 2 -p1
%patch -P 10 -p1
# remove all binary libs
find . -name "*.jar" -exec rm -f {} \;
find . -name "*.class" -exec rm -f {} \;

%build
%{ant} -Dcompile.source=1.8 -Dcompile.target=1.8 -Dj2se.apidoc=%{_javadocdir}/java package javadoc-link

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 build/%{name}-*-snap.jar %{buildroot}%{_javadir}/%{name}.jar

# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} %{SOURCE1} %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar -a jdom:jdom,org.jdom:jdom-legacy

# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}
cp -r build/apidocs %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}

# demo
install -dm 0755 %{buildroot}%{_datadir}/%{name}
cp -pr samples %{buildroot}%{_datadir}/%{name}
%fdupes -s %{buildroot}%{_datadir}/%{name}

%files -f .mfiles
%license LICENSE.txt
%doc CHANGES.txt COMMITTERS.txt README.txt TODO.txt

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE.txt

%files demo
%{_datadir}/%{name}
%license LICENSE.txt

%changelog
* Wed Feb 21 2024 Gus Kenion <gus.kenion@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Aug 24 2023 Fridrich Strba <fstrba@suse.com>
- Build only the jdom package and drop xom, jaxen and saxpath into
  separate standalone packages
- Removed patches:
  * jdom-1.1-build.xml.patch
  * jdom-1.1-xom-get-jaxen.patch
    + not needed with the current package
- Added patches:
  * CVE-2021-33813.patch
    + fix bsc#1187446, CVE-2021-33813: An XXE issue in SAXBuilder
    in JDOM through 2.0.6 allows attackers to cause a denial of
    service via a crafted HTTP request.
  * jdom-crosslink.patch
    + do not link to javadocs on web
  * no-jaxen.patch
    + do not fail to generate javadoc when jaxen is not present
- Modified patch:
  * jdom-1.1-OSGiManifest.patch
    + rediff
* Wed Mar 30 2022 Fridrich Strba <fstrba@suse.com>
- Build against the standalone JavaEE modules unconditionally
* Fri Mar 18 2022 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * jdom-1.1-build.xml.patch
    + Build with source/target levels 8
* Thu Mar 17 2022 Fridrich Strba <fstrba@suse.com>
- Build against standalone jaxb-api on distributions that have
  JDK without the JavaEE modules
* Wed Mar  2 2022 Fridrich Strba <fstrba@suse.com>
- Alias the xom artifact to the new com.io7m.xom groupId
* Fri May 14 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update jaxen to version 1.1.6
  * Bug fixes
* Tue Apr  6 2021 Andreas Schwab <schwab@suse.de>
- Increase java stack size to avoid overflow
* Tue Nov 12 2019 Fridrich Strba <fstrba@suse.com>
- Add correct requires for the packages so that they pull all
  required artifacts
- Clean up the packaging a bit
* Tue Mar 26 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade the jdom component to 1.1.3
- Modified patch:
  * jdom-1.1-build.xml.patch
    + Remove unneeded hunk
- Added patch:
  * jdom-1.1-OSGiManifest.patch
    + Make jdom an OSGi bundle
* Tue Nov 20 2018 Fridrich Strba <fstrba@suse.com>
- Removed patch:
  * include-glibj.jar.patch
    + The build works since ages without glibj being present, so
    removing any trace of it
* Tue Nov 20 2018 Fridrich Strba <fstrba@suse.com>
- Add maven pom files for the distributed jars
- Speed-up build by filtering out the failing files beforehand
  and then building all with one javac invocation
* Fri Sep 29 2017 fstrba@suse.com
- Fix build with jdk9: specify java source and target level 1.6
- Modified patch:
  * jdom-1.1-build.xml.patch
    + specify java source and target level 1.6
- Add more BuildRequires, in order to build more java files in
  stage 1
* Thu Sep 14 2017 fstrba@suse.com
- Build with javac whose syntax is compatible with OpenJDK
* Fri May 19 2017 tchvatal@suse.com
- Expand the buildignore lines for newer jdk
* Tue Mar 31 2015 tchvatal@suse.com
- Provide and obsolete jaxen-bootstrap to avoid file conflict
* Tue Mar 24 2015 tchvatal@suse.com
- Fix namespace clash with javapackages-tools on variables
* Tue Mar 24 2015 tchvatal@suse.com
- Cleanup with spec-cleaner and add debug output
* Fri Jun 15 2012 mvyskocil@suse.cz
- ignore jdk7 as well
* Mon Jun  4 2012 coolo@suse.com
- remove stray character from xom summary to fix UTF-8 parsing
* Thu Mar 17 2011 mvyskocil@suse.cz
- move to gcj back - the java.lang.StackOverflow is nothing nice
* Fri Mar 11 2011 mvyskocil@suse.cz
- build using openjdk, split BR one per-line
* Fri Mar 11 2011 mvyskocil@suse.cz
- build using openjdk, write one BuildRequire per line,
  no authors in description
* Wed May 20 2009 mvyskocil@suse.cz
- 'fixed bnc#501764: removed clover.license from source tarball'
* Mon May 18 2009 mvyskocil@suse.cz
- Removed documentation of ConcurrentReaderHashMap (bnc#504663)
  * dom4j-1.6.1/docs/clover/org/dom4j/tree/ConcurrentReaderHashMap.html
  * dom4j-1.6.1/docs/xref/org/dom4j/tree/ConcurrentReaderHashMap.html
* Thu May 14 2009 mvyskocil@suse.cz
- fixed version tag for jaxen and xom
* Tue Jan 20 2009 mvyskocil@suse.cz
- update jdom to 1.1 fixed bnc#467366
- updated jaxen to 1.1.1 (do not use an included jaxen)
- cleaned build requires
- Obsoleted java150 patch
* Fri Nov 21 2008 ro@suse.de
- update check-build.sh
* Wed Jan 23 2008 mvyskocil@suse.cz
- fixed beta build
* Thu Mar 29 2007 dbornkessel@suse.de
- added unzip to build requires
* Mon Jan 15 2007 dbornkessel@suse.de
- removed xml-commons-apis build req. (Bug #232127)
* Thu Sep 28 2006 dbornkessel@suse.de
- first versions
- fixes necessary to compile with Java 1.5.0
  - set source="1.4" and target="1.4" for ant "javac" tasks
  - set source="1.4" for ant "javadoc" tasks
